/*******************************************************************************
* File Name: SEG1_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "SEG1.h"

/* Check for removal by optimization */
#if !defined(SEG1_Sync_ctrl_reg__REMOVED)

static SEG1_BACKUP_STRUCT  SEG1_backup = {0u};

    
/*******************************************************************************
* Function Name: SEG1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG1_SaveConfig(void) 
{
    SEG1_backup.controlState = SEG1_Control;
}


/*******************************************************************************
* Function Name: SEG1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void SEG1_RestoreConfig(void) 
{
     SEG1_Control = SEG1_backup.controlState;
}


/*******************************************************************************
* Function Name: SEG1_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG1_Sleep(void) 
{
    SEG1_SaveConfig();
}


/*******************************************************************************
* Function Name: SEG1_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG1_Wakeup(void)  
{
    SEG1_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
