/*******************************************************************************
* File Name: SEG2_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "SEG2.h"

/* Check for removal by optimization */
#if !defined(SEG2_Sync_ctrl_reg__REMOVED)

static SEG2_BACKUP_STRUCT  SEG2_backup = {0u};

    
/*******************************************************************************
* Function Name: SEG2_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG2_SaveConfig(void) 
{
    SEG2_backup.controlState = SEG2_Control;
}


/*******************************************************************************
* Function Name: SEG2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void SEG2_RestoreConfig(void) 
{
     SEG2_Control = SEG2_backup.controlState;
}


/*******************************************************************************
* Function Name: SEG2_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG2_Sleep(void) 
{
    SEG2_SaveConfig();
}


/*******************************************************************************
* Function Name: SEG2_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG2_Wakeup(void)  
{
    SEG2_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
