/*******************************************************************************
* File Name: SEG3_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "SEG3.h"

/* Check for removal by optimization */
#if !defined(SEG3_Sync_ctrl_reg__REMOVED)

static SEG3_BACKUP_STRUCT  SEG3_backup = {0u};

    
/*******************************************************************************
* Function Name: SEG3_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG3_SaveConfig(void) 
{
    SEG3_backup.controlState = SEG3_Control;
}


/*******************************************************************************
* Function Name: SEG3_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void SEG3_RestoreConfig(void) 
{
     SEG3_Control = SEG3_backup.controlState;
}


/*******************************************************************************
* Function Name: SEG3_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG3_Sleep(void) 
{
    SEG3_SaveConfig();
}


/*******************************************************************************
* Function Name: SEG3_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SEG3_Wakeup(void)  
{
    SEG3_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
