#include "project.h"
#include "stdio.h"
#include "string.h"
#include "mtio.h"

char command[STR_LENGTH+1] ;
char operand[STR_LENGTH+1] ;

uint8_t code[] = {
      /*  '0'    '1'    '2'    '3'    '4'    '5'    '6'    '7' */
        0x3fu, 0x06u, 0x5bu, 0x4fu, 0x66u, 0x6du, 0x7du, 0x07u,
      /*  '8'    '9'    'A'    'B'    'C'    'D'    'E'    'F'   null */
        0x7fu, 0x6fu, 0x77u, 0x7cu, 0x39u, 0x5eu, 0x79u, 0x71u, 0x00u};

void str2lower(char *str)
{
    while(str && *str) {
        if (('A' <= *str) && (*str <= 'Z')) {
            *str += 'a' - 'A' ;
        }
        str++ ;
    }
}
    
void init_hardware(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */    
    UART_Start() ;
    UART_SpiUartClearRxBuffer() ;
    uart_int_ClearPending() ;
    uart_int_StartEx(uart_isr) ;
}

void splash(void)
{
    sprintf(str, "7SEG LED Test (%s %s)\n", __DATE__, __TIME__) ;
    print(str) ;
}

void help(void)
{
    print("=== usage ===\n") ;
    print("clear            : Clear LCD Display\n") ;
    print("0 <number>       : Display <number> in SEG0\n") ;
    print("1 <number>       : Display <number> in SEG1\n") ;
    print("2 <number>       : Display <number> in SEG2\n") ;
    print("3 <number>       : Display <number> in SEG3\n") ;
    print("d <0|1|2|3>      : Turn Dot On in SEG<0|1|2|3>\n") ;
    print("help             : print this message\n") ;
    print("=============\n") ;
}

void clear_segs(void)
{
    SEG0_Write(0x00) ;
    SEG1_Write(0x00) ;
    SEG2_Write(0x00) ;
    SEG3_Write(0x00) ;    
}

void do_command(char *cmd)
{
    uint32_t value ;
    uint8_t tmp ;
    
    str2lower(cmd) ;
    
    switch(*cmd) {
    case '0':
        get_string(operand) ;
        sscanf(operand, "%d", &value) ;
        if (value < 0x10) {
            SEG0_Write(code[value]) ;
            sprintf(str, "LCD(0) = %d\n", value) ;
            print(str) ;
        }
        break ;
    case '1':
        get_string(operand) ;
        sscanf(operand, "%d", &value) ;
        if (value < 0x10) {
            SEG1_Write(code[value]) ;
            sprintf(str, "LCD(1) = %d\n", value) ;
            print(str) ;
        }
        break ;        
    case '2':
        get_string(operand) ;
        sscanf(operand, "%d", &value) ;
        if (value < 0x10) {
            SEG2_Write(code[value]) ;
            sprintf(str, "LCD(2) = %d\n", value) ;
            print(str) ;
        }
        break ;            
    case '3':
        get_string(operand) ;
        sscanf(operand, "%d", &value) ;
        if (value < 0x10) {
            SEG3_Write(code[value]) ;
            sprintf(str, "LCD(3) = %d\n", value) ;
            print(str) ;
        }
        break ;          
    case 'd':
        get_string(operand) ;
        sscanf(operand, "%d", &value) ;
        switch(value) {
        case 0:
            tmp = SEG0_Read() ;
            SEG0_Write(tmp | 0x80) ;
            break ;
        case 1:
            tmp = SEG1_Read() ;
            SEG1_Write(tmp | 0x80) ;
            break ;
        case 2:
            tmp = SEG2_Read() ;
            SEG2_Write(tmp | 0x80) ;
            break ;            
        case 3:
            tmp = SEG3_Read() ;
            SEG3_Write(tmp | 0x80) ;
            break ;     
        }
        break ;
    case 'c':
        clear_segs() ;       
        break ;
    default:
        help() ;
        break ;
    }   
}

int main(void)
{
    init_hardware() ;
    
    splash() ;
    help() ;
    
    SEG0_Write(code[0]) ;
    SEG1_Write(code[1]) ;
    SEG2_Write(code[2]) ;
    SEG3_Write(code[3]) ;
    
    for(;;)
    {
        prompt() ;
        get_string(command) ;
        do_command(command) ;
    }
}
