#include "project.h"
#include "stdio.h"
#include "mtio.h"

#define TAB                  '\t'
#define SPACE                ' '
#define CR                   '\r'
#define LF                   '\n'
#ifndef STR_LENGTH
#define STR_LENGTH               128 /* buffer length for UART command input */
#endif

char          str[STR_LENGTH+1]     ; /* print buffer */
volatile char rx_buf[STR_LENGTH+1]  ; /* buffer for UART_RX */
volatile int  rx_index       = 0 ;
volatile int  str_received   = 0 ;

int is_delimiter(uint8_t c)
{
    int result = 0 ;
    switch(c) {
    case TAB:
    case SPACE:
    case CR:
    case LF:
        result = 1 ;
        break ;
    }
    return( result ) ;
}

CY_ISR(uart_isr)
{
    uint8_t c ;

    UART_ClearRxInterruptSource(UART_INTR_RX_NOT_EMPTY) ; /* for PSoC 4 */
    if (UART_SpiUartGetRxBufferSize()) { /*---*/

        c = UART_UartGetByte() ; /*---*/

        if ((rx_index >= STR_LENGTH) || is_delimiter(c)) {
            rx_buf[rx_index] = (char)0 ;
            str_received = 1 ;
            rx_index = 0 ;
        } else {
            rx_buf[rx_index++] = c ;
        }
    }
}    

void print(char *str)
{
    UART_UartPutString(str) ; /*---*/
}

void get_string(char *str)
{
    uint8_t int_flag ;
    
    while(str_received == 0) {
        ;
    }
    
    if (str_received) {
        int_flag = CyEnterCriticalSection() ;
        strcpy(str, (char *)rx_buf) ;
        str_received = 0 ;
        CyExitCriticalSection(int_flag) ;
    }
}

void prompt(void)
{
    print("> ") ;
}
